==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Διάταξη</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Μετακίνηση στο προσκήνιο</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Μετακίνηση προς τα εμπρός</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Μετακίνηση προς τα πίσω</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Μετακίνηση στο παρασκήνιο</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Επιλογή</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Επικόλληση</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Γενικές ρυθμίσεις</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Ρυθμίσεις εικόνας</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Χρώμα</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Χρώμα κειμένου</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Πλάτος</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Αρχικός αριθμός</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Συντελεστής θόλωσης</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Σκιά αντικειμένου</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Ρυθμίσεις αντικειμένου</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Κλείσιμο των άλλων</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Κλείσιμο όλων</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Κλείσιμο όλων στα αριστερά</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Κλείσιμο όλων στα δεξιά</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Επιλογή εργαλείου</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Ενεργοποιημένο</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Απενεργοποιημένο</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Π:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Υ:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Ορατότητα περιγράμματος και γέμισης</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Περίγραμμα και γέμιση</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Περίγραμμα χωρίς γέμιση</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Χωρίς περίγραμμα και χωρίς γέμιση</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Μέγεθος γραμματοσειράς</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Έντονα</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Πλάγια</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Υπογράμμιση</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Τεχνάσματα εικόνας</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Κανένα τέχνασμα</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Σκίαση</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Διαβαθμίσεις του γκρι</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Περίγραμμα</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Αντιστροφή χρωμάτων</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Με περιορισμούς</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Όταν είναι ενεργοποιημένο, εξαναγκάζει τον καμβά
να συμπεριλάβει την εικόνα παρασκηνίου.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Π:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Υ:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Χρώμα:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Χρώμα παρασκηνίου του καμβά</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Περιστροφή εικόνας</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° Δεξιόστροφα</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° Αριστερόστροφα</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Αυθαίρετα</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Οι θετικές τιμές περιστρέφουν σύμφωνα με τους δείκτες του ρολογιού, και οι αρνητικές τιμές αντίστροφα.
Η περιστροφή με πολλαπλασιαστές διαφορετικούς των 90° μπορεί να προκαλέσει απώλεια στην ποιότητα.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Οριζόντια</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Κατακόρυφα</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Περιστροφή</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Αναστροφή</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Κλιμάκωση της εικόνας</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Διατήρηση της αναλογίας διαστάσεων</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Πλάτος:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Ύψος:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Εικονοστοιχείο</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Ποσοστό</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Αυτοκόλλητο</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Επιλογή</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Γραφίδα</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Αριθμός</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Σημαδευτής ορθογωνίου</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Σημαδευτής έλλειψης</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Σημαδευτής γραφίδας</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Κείμενο</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Βέλος</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Διπλό βέλος</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Γραμμή</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Θόλωση</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Ορθογώνιο</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Έλλειψη</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Δρομέας αριθμού</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Αυτοκόλλητο</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Παραμόρφωση εικονοστοιχείων</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Δρομέας κειμένου</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Βέλος κειμένου</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Βέλος αριθμού</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Δημιουργία αντιγράφου</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Μεγέθυνση (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Σμίκρυνση (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Επαναφορά εστίασης (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.2.orig.tar.gz: kImageAnnotator-0.7.2/translations/kImageAnnotator_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Διάταξη</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Μετακίνηση στο προσκήνιο</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Μετακίνηση προς τα εμπρός</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Μετακίνηση προς τα πίσω</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Μετακίνηση στο παρασκήνιο</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Επιλογή</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Επικόλληση</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Γενικές ρυθμίσεις</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Ρυθμίσεις εικόνας</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Χρώμα</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Χρώμα κειμένου</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Πλάτος</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Αρχικός αριθμός</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Συντελεστής θόλωσης</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Σκιά αντικειμένου</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Ρυθμίσεις αντικειμένου</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Κλείσιμο των άλλων</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Κλείσιμο όλων</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Κλείσιμο όλων στα αριστερά</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Κλείσιμο όλων στα δεξιά</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Επιλογή εργαλείου</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Ενεργοποιημένο</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Απενεργοποιημένο</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">Περιστροφή</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Π:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Υ:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">Κατακόρυφα</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">Οριζόντια</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Εφαρμογή</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Ορατότητα περιγράμματος και γέμισης</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Περίγραμμα και γέμιση</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Περίγραμμα χωρίς γέμιση</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Χωρίς περίγραμμα και χωρίς γέμιση</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Μέγεθος γραμματοσειράς</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Έντονα</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Πλάγια</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Υπογράμμιση</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Τεχνάσματα εικόνας</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Κανένα τέχνασμα</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Σκίαση</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Διαβαθμίσεις του γκρι</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Περίγραμμα</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Αντιστροφή χρωμάτων</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Με περιορισμούς</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Όταν είναι ενεργοποιημένο, εξαναγκάζει τον καμβά
να συμπεριλάβει την εικόνα παρασκηνίου.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Π:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>Υ:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Χρώμα:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Χρώμα παρασκηνίου του καμβά</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Περιστροφή εικόνας</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° Δεξιόστροφα</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° Αριστερόστροφα</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Αυθαίρετα</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Οι θετικές τιμές περιστρέφουν σύμφωνα με τους δείκτες του ρολογιού, και οι αρνητικές τιμές αντίστροφα.
Η περιστροφή με πολλαπλασιαστές διαφορετικούς των 90° μπορεί να προκαλέσει απώλεια στην ποιότητα.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Οριζόντια</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Κατακόρυφα</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Περιστροφή</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Αναστροφή</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Κλιμάκωση της εικόνας</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Διατήρηση της αναλογίας διαστάσεων</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Πλάτος:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Ύψος:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Εικονοστοιχείο</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Ποσοστό</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Αυτοκόλλητο</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Επιλογή</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Γραφίδα</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Αριθμός</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Σημαδευτής ορθογωνίου</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Σημαδευτής έλλειψης</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Σημαδευτής γραφίδας</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Κείμενο</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Βέλος</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Διπλό βέλος</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Γραμμή</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Θόλωση</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Ορθογώνιο</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Έλλειψη</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Δρομέας αριθμού</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Αυτοκόλλητο</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Παραμόρφωση εικονοστοιχείων</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Δρομέας κειμένου</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Βέλος κειμένου</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Βέλος αριθμού</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Δημιουργία αντιγράφου</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Μεγέθυνση (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Σμίκρυνση (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Επαναφορά εστίασης (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
